==> better_with_time-2.0-sources.jar: com/bwt/blocks/AqueductBlock.java <==
package com.bwt.blocks;

import com.bwt.tags.BwtFluidTags;
import com.google.common.collect.ImmutableMap;
import com.google.common.collect.Maps;
import java.util.Map;
import net.minecraft.class_156;
import net.minecraft.class_1936;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_3610;

public class AqueductBlock extends class_2248 {
    public static final class_2746 NORTH = class_2741.field_12489;
    public static final class_2746 EAST = class_2741.field_12487;
    public static final class_2746 SOUTH = class_2741.field_12540;
    public static final class_2746 WEST = class_2741.field_12527;
    public static final Map<class_2350, class_2746> FACING_PROPERTIES = ImmutableMap.copyOf(class_156.method_654(Maps.newEnumMap(class_2350.class), directions -> {
        directions.put(class_2350.field_11043, NORTH);
        directions.put(class_2350.field_11034, EAST);
        directions.put(class_2350.field_11035, SOUTH);
        directions.put(class_2350.field_11039, WEST);
    }));

    public AqueductBlock(class_2251 settings) {
        super(settings);
        method_9590(method_9564()
                .method_11657(NORTH, false)
                .method_11657(SOUTH, false)
                .method_11657(EAST, false)
                .method_11657(WEST, false)
        );
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder);
        builder.method_11667(NORTH, SOUTH, EAST, WEST);
    }

    @Override
    protected class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        state = super.method_9559(state, direction, neighborState, world, pos, neighborPos);
        if (!neighborPos.equals(pos.method_10084())) {
            return state;
        }
        class_2680 noFlowState = state
                .method_11657(NORTH, false)
                .method_11657(SOUTH, false)
                .method_11657(EAST, false)
                .method_11657(WEST, false);
        class_3610 aboveFluidState = neighborState.method_26227();
        if (!aboveFluidState.method_15767(BwtFluidTags.AQUEDUCT_FLUIDS) || aboveFluidState.method_15771()) {
            return noFlowState;
        }
        for (class_2350 fluidAdjacentDirection : class_2350.class_2353.field_11062) {
            class_2338 fluidAdjacentPos = neighborPos.method_10093(fluidAdjacentDirection);
            class_3610 fluidAdjacentState = world.method_8316(fluidAdjacentPos);
            if (!fluidAdjacentState.method_15772().method_15780(aboveFluidState.method_15772())) {
                continue;
            }
            class_2680 neighborSupportingBlockState = world.method_8320(fluidAdjacentPos.method_10074());
            class_3610 neighborSupportingFluidState = neighborSupportingBlockState.method_26227();
            if (!neighborSupportingBlockState.method_51367() && (!neighborSupportingFluidState.method_15772().method_15780(fluidAdjacentState.method_15772()) || !neighborSupportingFluidState.method_15771())) {
                continue;
            }
            if (fluidAdjacentState.method_15761() < aboveFluidState.method_15761()) {
                continue;
            }
            // If the neighbor is an aqueduct source, it won't flow into this block if this block is the one flowing into it
            if (neighborSupportingBlockState.method_27852(this) && neighborSupportingBlockState.method_11654(FACING_PROPERTIES.get(fluidAdjacentDirection.method_10153()))) {
                continue;
            }
            state = state.method_11657(FACING_PROPERTIES.get(fluidAdjacentDirection), true);
        }
        return state;
    }
}

==> better_with_time-2.0.2-sources.jar: com/bwt/blocks/AqueductBlock.java <==
package com.bwt.blocks;

import com.bwt.tags.BwtFluidTags;
import com.google.common.collect.ImmutableMap;
import com.google.common.collect.Maps;
import java.util.Map;
import net.minecraft.class_156;
import net.minecraft.class_1936;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2415;
import net.minecraft.class_2470;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_3610;

public class AqueductBlock extends class_2248 {
    public static final class_2746 NORTH = class_2741.field_12489;
    public static final class_2746 EAST = class_2741.field_12487;
    public static final class_2746 SOUTH = class_2741.field_12540;
    public static final class_2746 WEST = class_2741.field_12527;
    public static final Map<class_2350, class_2746> FACING_PROPERTIES = ImmutableMap.copyOf(class_156.method_654(Maps.newEnumMap(class_2350.class), directions -> {
        directions.put(class_2350.field_11043, NORTH);
        directions.put(class_2350.field_11034, EAST);
        directions.put(class_2350.field_11035, SOUTH);
        directions.put(class_2350.field_11039, WEST);
    }));

    public AqueductBlock(class_2251 settings) {
        super(settings);
        method_9590(method_9564()
                .method_11657(NORTH, false)
                .method_11657(SOUTH, false)
                .method_11657(EAST, false)
                .method_11657(WEST, false)
        );
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder);
        builder.method_11667(NORTH, SOUTH, EAST, WEST);
    }

    @Override
    protected class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        state = super.method_9559(state, direction, neighborState, world, pos, neighborPos);
        if (!neighborPos.equals(pos.method_10084())) {
            return state;
        }
        class_2680 noFlowState = state
                .method_11657(NORTH, false)
                .method_11657(SOUTH, false)
                .method_11657(EAST, false)
                .method_11657(WEST, false);
        class_3610 aboveFluidState = neighborState.method_26227();
        if (!aboveFluidState.method_15767(BwtFluidTags.AQUEDUCT_FLUIDS) || aboveFluidState.method_15771()) {
            return noFlowState;
        }
        for (class_2350 fluidAdjacentDirection : class_2350.class_2353.field_11062) {
            class_2338 fluidAdjacentPos = neighborPos.method_10093(fluidAdjacentDirection);
            class_3610 fluidAdjacentState = world.method_8316(fluidAdjacentPos);
            if (!fluidAdjacentState.method_15772().method_15780(aboveFluidState.method_15772())) {
                continue;
            }
            class_2680 neighborSupportingBlockState = world.method_8320(fluidAdjacentPos.method_10074());
            class_3610 neighborSupportingFluidState = neighborSupportingBlockState.method_26227();
            if (!neighborSupportingBlockState.method_51367() && (!neighborSupportingFluidState.method_15772().method_15780(fluidAdjacentState.method_15772()) || !neighborSupportingFluidState.method_15771())) {
                continue;
            }
            if (fluidAdjacentState.method_15761() < aboveFluidState.method_15761()) {
                continue;
            }
            // If the neighbor is an aqueduct source, it won't flow into this block if this block is the one flowing into it
            if (neighborSupportingBlockState.method_27852(this) && neighborSupportingBlockState.method_11654(FACING_PROPERTIES.get(fluidAdjacentDirection.method_10153()))) {
                continue;
            }
            state = state.method_11657(FACING_PROPERTIES.get(fluidAdjacentDirection), true);
        }
        return state;
    }


    @Override
    protected class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return switch (rotation) {
            case field_11464 -> state.method_11657(NORTH, state.method_11654(SOUTH))
                    .method_11657(EAST, state.method_11654(WEST))
                    .method_11657(SOUTH, state.method_11654(NORTH))
                    .method_11657(WEST, state.method_11654(EAST));
            case field_11465 -> state.method_11657(NORTH, state.method_11654(EAST))
                    .method_11657(EAST, state.method_11654(SOUTH))
                    .method_11657(SOUTH, state.method_11654(WEST))
                    .method_11657(WEST, state.method_11654(NORTH));
            case field_11463 -> state.method_11657(NORTH, state.method_11654(WEST))
                    .method_11657(EAST, state.method_11654(NORTH))
                    .method_11657(SOUTH, state.method_11654(EAST))
                    .method_11657(WEST, state.method_11654(SOUTH));
            default -> state;
        };
    }

    @Override
    protected class_2680 method_9569(class_2680 state, class_2415 mirror) {
        return switch (mirror) {
            case field_11300 -> state.method_11657(NORTH, state.method_11654(SOUTH)).method_11657(SOUTH, state.method_11654(NORTH));
            case field_11301 -> state.method_11657(EAST, state.method_11654(WEST)).method_11657(WEST, state.method_11654(EAST));
            default -> super.method_9569(state, mirror);
        };
    }
}
